==> nextcloud-app-contacts-7.3.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/be.js <==
OC.L10N.register(
    "contacts",
    {
    "All contacts" : "Усе кантакты",
    "Contacts" : "Кантакты",
    "Copy to full name" : "Скапіяваць у поўнае імя",
    "Please select a team" : "Выберыце каманду",
    "Loading team…" : "Загрузка каманды…",
    "Loading contacts …" : "Загрузка кантактаў …",
    "There are no contacts yet" : "Пакуль няма кантактаў.",
    "Create contact" : "Стварыць кантакт",
    "Create contacts" : "Стварыць кантакты",
    "Add contacts" : "Дадаць кантакты",
    "Loading …" : "Загрузка …",
    "Manage team" : "Кіраванне камандай",
    "Leave team" : "Выйсці з каманды",
    "Delete team" : "Выдаліць каманду",
    "General settings" : "Агульныя налады",
    "Rename" : "Перайменаваць",
    "Export" : "Экспарт",
    "Delete" : "Выдаліць",
    "Show all groups" : "Паказаць усе групы",
    "Show all teams" : "Паказаць усе каманды",
    "Contact groups" : "Групы кантактаў",
    "Contact group name" : "Назва групы кантактаў",
    "Copy link" : "Скапіяваць спасылку",
    "This will unshare the address book and every contacts within it" : "Будзе скасавана абагульванне адраснай кнігі і ўсіх кантактаў у ёй",
    "Unshare {addressbook}?" : "Скасаваць абагульванне {addressbook}?",
    "Unshare from me" : "Скасаваць абагульванне са мной",
    "_%n group_::_%n groups_" : ["%n група","%n групы","%n груп","%n груп"],
    "No users or groups" : "Няма карыстальнікаў або груп",
    "Add" : "Дадаць",
    "First name" : "Імя",
    "Last name" : "Прозвішча",
    "Save" : "Захаваць",
    "Team name" : "Назва каманды",
    "Edit" : "Рэдагаваць",
    "Cancel" : "Скасаваць",
    "Members" : "Удзельнікі",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Кантакт, які вы спрабавалі рэдагаваць, змяніўся. Абнавіце кантакт уручную. Усе далейшыя змены будуць адхілены.",
    "Add contact to Birthday Calendar" : "Дадаць кантакт у каляндар дзён нараджэння",
    "Exclude contact from Birthday Calendar" : "Выключыць кантакт з календара дзён нараджэння",
    "Name" : "Імя",
    "Title" : "Загаловак",
    "Groups" : "Групы",
    "Add to {group}" : "Дадаць у {group}",
    "Add to group" : "Дадаць у групу",
    "New team name" : "Назва новай каманды",
    "Remove member" : "Выдаліць удзельніка",
    "Add to {circle}" : "Дадаць у {circle}",
    "Pending" : "У чаканні",
    "Add contact in group" : "Дадаць кантакт у групу",
    "Member" : "Удзельнік",
    "Add member" : "Дадаць удзельніка",
    "Close" : "Закрыць",
    "User" : "Карыстальнік",
    "Group" : "Група",
    "Email" : "Электронная пошта",
    "Owner" : "Уладальнік",
    "Users" : "Карыстальнікі",
    "Additional names" : "Дадатковыя імёны",
    "Nickname" : "Псеўданім",
    "Notes" : "Нататкі",
    "Website" : "Вэб-сайт",
    "Location" : "Месцазнаходжанне",
    "Home" : "Дадому",
    "Address" : "Адрас",
    "Birthday" : "Дзень нараджэння",
    "Place of birth" : "Месца нараджэння",
    "Unknown" : "Невядомы"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-contacts-7.3.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/be.js <==
OC.L10N.register(
    "contacts",
    {
    "All contacts" : "Усе кантакты",
    "Contacts" : "Кантакты",
    "Copy to full name" : "Скапіяваць у поўнае імя",
    "Please select a team" : "Выберыце каманду",
    "Loading team…" : "Загрузка каманды…",
    "Loading contacts …" : "Загрузка кантактаў …",
    "There are no contacts yet" : "Пакуль няма кантактаў.",
    "Create contact" : "Стварыць кантакт",
    "Create contacts" : "Стварыць кантакты",
    "Add contacts" : "Дадаць кантакты",
    "Loading …" : "Загрузка …",
    "Manage team" : "Кіраванне камандай",
    "Leave team" : "Выйсці з каманды",
    "Delete team" : "Выдаліць каманду",
    "General settings" : "Агульныя налады",
    "Rename" : "Перайменаваць",
    "Export" : "Экспарт",
    "Delete" : "Выдаліць",
    "Show all groups" : "Паказаць усе групы",
    "Show all teams" : "Паказаць усе каманды",
    "Contact groups" : "Групы кантактаў",
    "Contact group name" : "Назва групы кантактаў",
    "Copy link" : "Скапіяваць спасылку",
    "This will unshare the address book and every contacts within it" : "Будзе скасавана абагульванне адраснай кнігі і ўсіх кантактаў у ёй",
    "Unshare {addressbook}?" : "Скасаваць абагульванне {addressbook}?",
    "Unshare from me" : "Скасаваць абагульванне са мной",
    "_%n group_::_%n groups_" : ["%n група","%n групы","%n груп","%n груп"],
    "No users or groups" : "Няма карыстальнікаў або груп",
    "Add" : "Дадаць",
    "First name" : "Імя",
    "Last name" : "Прозвішча",
    "Save" : "Захаваць",
    "Team name" : "Назва каманды",
    "Edit" : "Рэдагаваць",
    "Cancel" : "Скасаваць",
    "Members" : "Удзельнікі",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Кантакт, які вы спрабавалі рэдагаваць, змяніўся. Абнавіце кантакт уручную. Усе далейшыя змены будуць адхілены.",
    "Add contact to Birthday Calendar" : "Дадаць кантакт у каляндар дзён нараджэння",
    "Exclude contact from Birthday Calendar" : "Выключыць кантакт з календара дзён нараджэння",
    "Name" : "Імя",
    "Title" : "Загаловак",
    "Groups" : "Групы",
    "Add to {group}" : "Дадаць у {group}",
    "Add to group" : "Дадаць у групу",
    "New team name" : "Назва новай каманды",
    "Promote as sole owner" : "Прызначыць як адзінага ўладальніка",
    "Promote to {level}" : "Павысіць да {level}",
    "Remove member" : "Выдаліць удзельніка",
    "Add to {circle}" : "Дадаць у {circle}",
    "Pending" : "У чаканні",
    "Add contact in group" : "Дадаць кантакт у групу",
    "Member" : "Удзельнік",
    "Add member" : "Дадаць удзельніка",
    "Close" : "Закрыць",
    "User" : "Карыстальнік",
    "Group" : "Група",
    "Email" : "Электронная пошта",
    "Owner" : "Уладальнік",
    "Users" : "Карыстальнікі",
    "Additional names" : "Дадатковыя імёны",
    "Nickname" : "Псеўданім",
    "Notes" : "Нататкі",
    "Website" : "Вэб-сайт",
    "Location" : "Месцазнаходжанне",
    "Home" : "Дадому",
    "Address" : "Адрас",
    "Birthday" : "Дзень нараджэння",
    "Place of birth" : "Месца нараджэння",
    "Unknown" : "Невядомы"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
